@@ -82,10 +82,11 @@ class RestCall(Logger):
             # else:
             #     resp = get(url= u, auth = self._auth, headers={'Accept': 'application/json'})
 
+            header = {}
             if self._accept_json:
-                resp = self._session.get(u, timeout = (5, 15),auth=self._auth,headers={'Accept': 'application/json'})
-            else:
-                resp = self._session.get(u, timeout = (5, 15),auth=self._auth)
+                header['Accept']='application/json'
+            resp = self._session.get(u, timeout = (5, 15),auth=self._auth,headers=header)
+
             resp.raise_for_status()
 
             # Save the duration, if enabled.
@@ -102,18 +103,18 @@ class RestCall(Logger):
             else:
                 return resp.status_code,""
 
-        except exceptions.ConnectionError:
-            self.error(f'Unable to connect to host {self._base_url}')
-        except exceptions.Timeout:
+        except exceptions.ConnectionError as ex:
+            self.error(f'Unable to connect to host {self._base_url} ({ex})')
+        except exceptions.Timeout as ex:
             #TODO Maybe set up for a retry, or continue in a retry loop
-            self.error(f'Timeout while performing api request using: {url}')
-        except exceptions.TooManyRedirects:
+            self.error(f'Timeout while performing api request using: {url} ({ex})')
+        except exceptions.TooManyRedirects as ex:
             #TODO Tell the user their URL was bad and try a different one
-            self.error(f'TooManyRedirects while performing api request using: {url}')
+            self.error(f'TooManyRedirects while performing api request using: {url} ({ex})')
         except exceptions.HTTPError as e:
             self.error(e)
         except exceptions.RequestException as e:
             # catastrophic error. bail.
-            self.error(f'General Request exception while performing api request using: {u}')
+            self.error(f'General Request exception while performing api request using: {u} ({e})')
 
         return 0, "{}"
