@@ -144,9 +144,12 @@ def check_process(process:Popen,output=True):
         if output == True and len(line.strip(' ')) > 0:
             print(line)
         ret.append(line)
-    stdout, stderr = process.communicate()
+    try:
+        stdout, stderr = process.communicate()
+    except: 
+        return process.returncode,ret
     return process.returncode,ret
-    
+     
 def format_table(writer, data, sheet_name,width=None):
     
     data.to_excel(writer, index=False, sheet_name=sheet_name, startrow=1,header=False)
